@@ -6,6 +6,15 @@ from django.conf import settings
 from django.db.models import get_app, get_apps
 from django.core.management.base import BaseCommand
 
+# Django versions prior to 1.2 don't include the DjangoTestSuiteRunner class;
+# Django versions since 1.2 include multi-database support, which doesn't play
+# nicely with the database setup in the XML test runner.
+try:
+    from django.test.simple import DjangoTestSuiteRunner
+    xml_runner = 'test_extensions.testrunners.xmloutput.XMLTestSuiteRunner'
+except ImportError:  # We are in a version prior to 1.2
+    xml_runner = 'test_extensions.testrunners.xmloutput.run_tests'
+
 skippers = []
 
 class Command(BaseCommand):
@@ -77,7 +86,7 @@ class Command(BaseCommand):
         elif options.get('figleaf'):
             test_runner_name = 'test_extensions.testrunners.figleafcoverage.run_tests'
         elif options.get('xml'):
-            test_runner_name = 'test_extensions.testrunners.xmloutput.run_tests'
+            test_runner_name = xml_runner
         else:
             test_runner_name = settings.TEST_RUNNER
 
@@ -105,8 +114,7 @@ class Command(BaseCommand):
         test_options = dict(verbosity=verbosity,
             interactive=interactive)
             
-        if failfast:
-            test_options["failfast"] = failfast
+        test_options["failfast"] = failfast
 
         if options.get('coverage'):
             test_options["callgraph"] = callgraph
